@@ -23,16 +23,16 @@ always.dag.result = c(score.based.algorithms, hybrid.algorithms)
 available.mvber.vartests = c("tvar", "gvar", "nvar")
 
 method.labels = c(
-  'gs' = "grow-shrink",
-  'iamb' = "incremental association",
-  'fast.iamb' = "fast incremental association",
-  'inter.iamb' = "interleaved incremental association",
+  'gs' = "Grow-Shrink",
+  'iamb' = "Incremental Association",
+  'fast.iamb' = "Fast Incremental Association",
+  'inter.iamb' = "Interleaved Incremental Association",
   'rnd' = "random/generated",
-  'hc' = 'hill-climbing',
-  'tabu' = 'tabu search',
-  'mmpc' = 'max-min parent children',
-  'rsmax2' = 'two-phase restricted maximization',
-  'mmhc' = 'max-min hill climbing'
+  'hc' = 'Hill-Climbing',
+  'tabu' = 'Tabu Search',
+  'mmpc' = 'Max-min Parent Children',
+  'rsmax2' = 'Two-Phase Restricted Maximization',
+  'mmhc' = 'Max-Min Hill Climbing'
 )
 
 method.extra.args = list(
@@ -41,30 +41,30 @@ method.extra.args = list(
 )
 
 test.labels = c(
-  'mi' = "mutual information (discrete)",
-  'mi-sh' = "mutual information (discrete, shrinkage)",
-  'mc-mi' = "mutual information (discrete, Monte Carlo)",
-  'mi-g' = "mutual information (gaussian)",
-  'mc-mi-g' = "mutual information (gaussian, Monte Carlo)",
-  'aict'= "AIC-like test",
+  'mi' = "Mutual Information (discrete)",
+  'mi-sh' = "Mutual Information (discrete, shrinkage)",
+  'mc-mi' = "Mutual Information (discrete, Monte Carlo)",
+  'mi-g' = "Mutual Information (Gaussian)",
+  'mc-mi-g' = "Mutual Information (Gaussian, Monte Carlo)",
+  'aict'= "AIC-like Test",
   'x2'= "Pearson's X^2",
   'mc-x2'= "Pearson's X^2 (Monte Carlo)",
-  'cor' = "linear correlation",
-  'mc-cor' = "linear correlation (Monte Carlo)",
-  'zf' = "Fisher's Z test",
-  'mc-zf' = "Fisher's Z test (Monte Carlo)"
+  'cor' = "Pearson's Linear Correlation",
+  'mc-cor' = "Pearson's Linear Correlation (Monte Carlo)",
+  'zf' = "Fisher's Z Test",
+  'mc-zf' = "Fisher's Z Test (Monte Carlo)"
 )
 
 score.labels = c(
   'k2' = "Cooper & Herskovits' K2",
-  'bde' = "bayesian-dirichlet (score equivalent)",
-  'aic' = "Akaike information criterion",
-  'bic' = "bayesian information criterion",
-  'loglik' = "log-likelihood",
-  'bge' = "bayesian-gaussian (score equivalent)",
-  'loglik-g' = "log-likelihood (gaussian)",
-  'aic-g' = "Akaike information criterion (gaussian)",
-  'bic-g' = "bayesian information criterion (gaussian)"
+  'bde' = "Bayesian Dirichlet (BDeu)",
+  'aic' = "Akaike Information Criterion",
+  'bic' = "Bayesian Information Criterion",
+  'loglik' = "Log-Likelihood",
+  'bge' = "Bayesian Gaussian (score equivalent)",
+  'loglik-g' = "Log-Likelihood (BGe)",
+  'aic-g' = "Akaike Information Criterion (Gaussian)",
+  'bic-g' = "Bayesian Information Criterion (Gaussian)"
 )
 
 score.extra.args = list(
@@ -85,9 +85,10 @@ score.extra.args = list(
 graph.generation.algorithms = c("ordered", "ic-dag", "melancon", "empty")
 
 graph.generation.labels = c(
-  "ordered" = "full ordering",
-  "ic-dag" = "multiconnected dags",
-  "empty" = "empty"
+  "ordered" = "Full Ordering",
+  "ic-dag" = "Ide & Cozman's Multiconnected DAGs",
+  "melancon" = "Melancon's Uniform Probability DAGs",
+  "empty" = "Empty"
 )
 
 graph.generation.extra.args = list(
@@ -97,9 +98,9 @@ graph.generation.extra.args = list(
 )
 
 mvber.labels = list(
-  "tvar" = "total variance",
-  "gvar" = "generalized variance",
-  "nvar" = "squared Frobenius norm"
+  "tvar" = "Total Variance",
+  "gvar" = "Generalized Variance",
+  "nvar" = "Squared Frobenius Norm"
 )
 
 graphviz.enabled = FALSE
