@@ -481,31 +481,31 @@ PropCost[PropCost == "Million:HundredThou"] = sample(VALUE2, length(which(PropCo
 PropCost[PropCost == "Million:Million"] = sample(VALUE2, length(which(PropCost == "Million:Million")), prob = c(0, 0, 0, 1), replace = TRUE)
 
 insurance = data.frame(
- GoodStudent = GoodStudent, 
- Age = Age,
- SocioEcon = SocioEcon,
- RiskAversion = RiskAversion,
- VehicleYear = VehicleYear,
- ThisCarDam = ThisCarDam,
- RuggedAuto = RuggedAuto,
- Accident = Accident,
- MakeModel = MakeModel,
- DrivQuality = DrivQuality,
- Mileage = Mileage,
- Antilock = Antilock,
- DrivingSkill = DrivingSkill,
- SeniorTrain = SeniorTrain,
- ThisCarCost = ThisCarCost,
- Theft = Theft,
- CarValue = CarValue,
- HomeBase = HomeBase,
- AntiTheft = AntiTheft,
- PropCost = PropCost,
- OtherCarCost = OtherCarCost,
- OtherCar = OtherCar,
- MedCost = MedCost,
- Cushioning = Cushioning,
- Airbag = Airbag,
- ILiCost = ILiCost,
- DrivHist = DrivHist
+  GoodStudent = factor(GoodStudent, levels = BOOL), 
+  Age = factor(Age, levels = AGE),
+  SocioEcon = factor(SocioEcon, levels = SEC),
+  RiskAversion = factor(RiskAversion, levels = RISK),
+  VehicleYear = factor(VehicleYear, levels = YEAR),
+  ThisCarDam = factor(ThisCarDam, levels = ACC),
+  RuggedAuto = factor(RuggedAuto, levels = RUGGED),
+  Accident = factor(Accident, levels = ACC),
+  MakeModel = factor(MakeModel, levels = MODEL),
+  DrivQuality = factor(DrivQuality, levels = SKILL2),
+  Mileage = factor(Mileage, levels = MIL),
+  Antilock = factor(Antilock, levels = BOOL),
+  DrivingSkill = factor(DrivingSkill, levels = SKILL),
+  SeniorTrain = factor(SeniorTrain, levels = BOOL),
+  ThisCarCost = factor(ThisCarCost, levels = VALUE2),
+  Theft = factor(Theft, levels = BOOL),
+  CarValue = factor(CarValue, levels = VALUE),
+  HomeBase = factor(HomeBase, levels = HOME),
+  AntiTheft = factor(AntiTheft, levels = BOOL),
+  PropCost = factor(PropCost, levels = VALUE2),
+  OtherCarCost = factor(OtherCarCost, levels = VALUE2),
+  OtherCar = factor(OtherCar, levels = BOOL),
+  MedCost = factor(MedCost, levels = VALUE2),
+  Cushioning = factor(Cushioning, levels = SKILL3),
+  Airbag = factor(Airbag, levels = BOOL),
+  ILiCost = factor(ILiCost, levels = VALUE2),
+  DrivHist = factor(DrivHist, levels = HIST)
 )
